@@ -2,6 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "நாட்காட்டி",
+    "Personal" : "தனிப்பட்ட",
     "Today" : "இன்று",
     "Week" : "வாரம்",
     "Month" : "மாதம்",
@@ -15,6 +16,7 @@ OC.L10N.register(
     "Delete permanently" : "நிரந்தரமாக நீக்கவும்",
     "Share link" : "Share link",
     "can edit" : "தொகுக்க முடியும்",
+    "Save" : "சேமிக்க ",
     "Cancel" : "இரத்து செய்க",
     "Actions" : "செயல்கள்",
     "Location" : "இடம்",
@@ -27,7 +29,6 @@ OC.L10N.register(
     "Friday" : "வெள்ளிக்கிழமை",
     "Saturday" : "சனிக்கிழமை",
     "Sunday" : "ஞாயிற்றுக்கிழமை",
-    "Save" : "சேமிக்க ",
     "Update" : "இற்றைப்படுத்தல்",
     "Your email address" : "உங்களுடைய மின்னஞ்சல் முகவரி",
     "Email" : "மின்னஞ்சல்",
@@ -35,12 +36,9 @@ OC.L10N.register(
     "Repeat" : "மீண்டும்",
     "never" : "ஒருபோதும்",
     "More" : "மேலதிக",
-    "Personal" : "தனிப்பட்ட",
     "Details" : "விவரங்கள்",
     "Attendees" : "பங்கேற்பாளர்கள்",
     "Close" : "மூடுக",
-    "Prev" : "Prev",
-    "Next" : "அடுத்த",
     "Other" : "மற்றவை",
     "Birthday" : "பிறந்த நாள்"
 },
